summaryrefslogtreecommitdiff
path: root/libopie2/opienet/onetwork.h
Side-by-side diff
Diffstat (limited to 'libopie2/opienet/onetwork.h') (more/less context) (ignore whitespace changes)
-rw-r--r--libopie2/opienet/onetwork.h29
1 files changed, 22 insertions, 7 deletions
diff --git a/libopie2/opienet/onetwork.h b/libopie2/opienet/onetwork.h
index b170ea2..e1545dd 100644
--- a/libopie2/opienet/onetwork.h
+++ b/libopie2/opienet/onetwork.h
@@ -363,3 +363,3 @@ class OWirelessNetworkInterface : public ONetworkInterface
*/
- virtual void setMonitorMode( bool ); //FIXME: ==> setMode( "monitor" );
+ virtual void setMonitorMode( bool ); //FIXME: ==> setMode( "monitor" ); Use IW_MONITOR first, if this doesn't work, then use iwpriv!
/**
@@ -399,8 +399,10 @@ class OWirelessNetworkInterface : public ONetworkInterface
virtual void getPrivate( const QString& command ); //FIXME: Implement and document this
-
- virtual bool isAssociated() const {}; //FIXME: Implement and document this
/**
- * @returns the MAC address of the Access Point if the
- * device is in infrastructure mode. @returns a (more or less random) CELL
- * address if the device is in adhoc mode.
+ * @returns true if the interface is associated to an access point
+ * @note: This information is only valid if the interface is in managed mode.
+ */
+ virtual bool isAssociated() const;
+ /**
+ * @returns the MAC address of the Access Point if the device is in infrastructure mode.
+ * @returns a (more or less random) cell ID address if the device is in adhoc mode.
*/
@@ -416,6 +418,12 @@ class OWirelessNetworkInterface : public ONetworkInterface
virtual QString SSID() const;
+ /**
+ * Perform scanning the wireless network neighbourhood.
+ * @note: UNSTABLE API - UNDER CONSTRUCTION - DON'T USE!
+ */
+ virtual int scanNetwork();
protected:
- void buildChannelList();
+ void buildInformation();
void buildPrivateList();
+ void dumpInformation() const;
virtual void init();
@@ -428,2 +436,3 @@ class OWirelessNetworkInterface : public ONetworkInterface
QMap<int,int> _channels;
+ struct iw_range _range;
@@ -477,2 +486,3 @@ class OCiscoMonitoringInterface : public OMonitoringInterface
+
/*======================================================================================
@@ -481,2 +491,3 @@ class OCiscoMonitoringInterface : public OMonitoringInterface
+
class OWlanNGMonitoringInterface : public OMonitoringInterface
@@ -494,2 +505,3 @@ class OWlanNGMonitoringInterface : public OMonitoringInterface
+
/*======================================================================================
@@ -498,2 +510,3 @@ class OWlanNGMonitoringInterface : public OMonitoringInterface
+
class OHostAPMonitoringInterface : public OMonitoringInterface
@@ -509,2 +522,3 @@ class OHostAPMonitoringInterface : public OMonitoringInterface
+
/*======================================================================================
@@ -513,2 +527,3 @@ class OHostAPMonitoringInterface : public OMonitoringInterface
+
class OOrinocoMonitoringInterface : public OMonitoringInterface